#!/bin/sh

ACTION=${1}
shift 1

get_image() {
  IMAGE_NAME=$(uci get neko.@neko[0].image_name 2>/dev/null)
}

do_install_detail() {
  local config=$(uci get neko.@neko[0].config_path 2>/dev/null)
  local port=$(uci get neko.@neko[0].port 2>/dev/null)
  local IMAGE_NAME=$(uci get neko.@neko[0].image_name 2>/dev/null)
  
  GEN_PASS=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  GEN_PASS2=$(< /dev/urandom tr -dc A-Za-z0-9 2>/dev/null | head -c14; echo)
  
  LAN_IP=$(uci get network.lan.ipaddr)
  LAN_IP="${LAN_IP%/*}"
  
  if [ -z "$config" ]; then
    echo "config path is empty!"
    exit 1
  fi

  [ -z "$port" ] && port=8281
  [ -z "$IMAGE_NAME" ] && IMAGE_NAME="m1k1o/neko:firefox"

  rm -R /opt/docker2/compose/neko-app
  mkdir /opt/docker2/compose/neko-app

  touch /opt/docker2/compose/neko-app/docker-compose.yml
  cat > /opt/docker2/compose/neko-app/docker-compose.yml <<EOF
version: "3.4"
services:
  neko:
    image: $IMAGE_NAME
    restart: "unless-stopped"
    shm_size: "2gb"
    ports:
      - "$port:8080"
      - "52000-52005:52000-52005/udp"
    environment:
      NEKO_SCREEN: '1920x1080@30'
      NEKO_PASSWORD: meowmix
      NEKO_PASSWORD_ADMIN: ${GEN_PASS}
      NEKO_EPR: 52000-52005
      NEKO_NAT1TO1: $config
    labels:
      plugsy.name: "neko"
      plugsy.category: "Home"
      plugsy.icon: "@styled-icons/entypo/Cat"
      plugsy.link: "http://$config:$port"
EOF

  docker-compose -f /opt/docker2/compose/neko-app/docker-compose.yml up -d

  uci add shortcutmenu lists
  uci set shortcutmenu.@lists[-1].webname="$IMAGE_NAME"
  uci set shortcutmenu.@lists[-1].weburl="$config:$port"
  uci set shortcutmenu.@lists[-1].webpath="/"
  uci commit shortcutmenu

  echo "Your Neko admin password is: $GEN_PASS"
  echo "The default password for viewers is: meowmix"
}

usage() {
  echo "usage: $0 sub-command"
  echo "where sub-command is one of:"
  echo "      install                Install Neko"
  echo "      upgrade                Upgrade Neko"
  echo "      rm/start/stop/restart  Remove/Start/Stop/Restart Neko"
  echo "      status                 Neko status"
  echo "      port                   Neko port"
}

case ${ACTION} in
  "install"|"upgrade")
    get_image
    do_install_detail
  ;;
  "rm")
    get_image
    CONTAINER_IDS=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.ID}}')
    echo "Stopping and removing containers..."
    for ID in $CONTAINER_IDS; do
      docker stop $ID
      docker rm $ID
    done
    docker rmi -f $IMAGE_NAME
  ;;
  "start"|"stop"|"restart")
    get_image
    CONTAINER_IDS=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.ID}}')
    for ID in $CONTAINER_IDS; do
      docker ${ACTION} $ID
    done
  ;;
  "status")
    get_image
    CONTAINER_NAMES=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Names}}')
    docker ps --all -f "name=${CONTAINER_NAMES}" --format '{{.Status}}'
  ;;
  "port")
    get_image
    CONTAINER_NAMES=$(docker ps -a --filter "ancestor=${IMAGE_NAME}" --format '{{.Names}}')
    docker ps --all -f "name=${CONTAINER_NAMES}" --format '{{.Ports}}' | grep -om1 '0.0.0.0:[0-9]*' | sed 's/0.0.0.0://'
  ;;
  *)
    usage
    exit 1
  ;;
esac